pub type Snapshot<T: Config> = StorageValue<_GeneratedPrefixForStorageSnapshot<T>, RoundSnapshot<T::AccountId, VoterOf<T>>>;Expand description
Snapshot data of the round.
This is created at the beginning of the signed phase and cleared upon calling elect.
Note: This storage type must only be mutated through SnapshotWrapper.
Storage type is StorageValue with value type RoundSnapshot < T :: AccountId, VoterOf < T > >.
Aliased Type
struct Snapshot<T: Config>(/* private fields */);